# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class AlertCategoryListEnum(object):

    """Implementation of the 'AlertCategoryList' enum.

    Specifies a list of Alert Categories to filter alert types by.
    Specifies the category of an Alert.
    kDisk - Alert associated with the disk.
    kNode - Alert associated with general hardware on a specific node.
    kCluster - Alert associated with general hardware in cluster level.
    kChassis - Alert associated with the Chassis.
    kPowerSupply - Alert associated with the power supply.
    kCPU - Alert associated with the CPU usage.
    kMemory - Alert associated with the RAM/Memory.
    kTemperature - Alert associated with the temperature.
    kFan - Alert associated with the fan.
    kNIC - Alert associated with network chips and interfaces.
    kFirmware - Alert associated with the firmware.
    kNodeHealth - Alert associated with node health status.
    kOperatingSystem - Alert associated with operating systems.
    kDataPath - Alert associated with data management in the cluster.
    kMetadata - Alert associated with metadata management.
    kIndexing - Alert associated with indexing services.
    kHelios - Alert associated with Helios.
    kAppMarketPlace - Alert associated with App MarketPlace.
    kLicense - Alert associated with licensing.
    kSecurity - Alert associated with security.
    kUpgrade - Alert associated with upgrade activities.
    kClusterManagement - Alert associated with cluster management activities.
    kAuditLog - Alert associated with audit log events.
    kNetworking - Alert associated with networking issue.
    kConfiguration - Alert associated with cluster or system configurations.
    kStorageUsage - Alert associated with the disk/domain/cluster storage usage.
    kFaultTolerance - Alert associated with the fault tolerance in different levels.
    kBackupRestore - Alert associated with Backup-Restore job.
    kArchivalRestore - Alert associated with Archival-Restore job.
    kRemoteReplication - Alert associated with Replication job.
    kQuota - Alert associated with Quotas.
    kCDP - Alert associated with Continuous Data Protection.
    kViewFailover - Alert associated with view Failover.
    kDisasterRecovery - Alert associated with Disaster Recovery.


    Attributes:
    KDISK: TODO: type description here.
    KNODE: TODO: type description here.
    KCLUSTER: TODO: type description here.
    KCHASSIS: TODO: type description here.
    KPOWERSUPPLY: TODO: type description here.
    KCPU: TODO: type description here.
    KMEMORY: TODO: type description here.
    KTEMPERATURE: TODO: type description here.
    KFAN: TODO: type description here.
    KNIC: TODO: type description here.
    KFIRMWARE: TODO: type description here.
    KNODEHEALTH: TODO: type description here.
    KOPERATINGSYSTEM: TODO: type description here.
    KDATAPATH: TODO: type description here.
    KMETADATA: TODO: type description here.
    KINDEXING: TODO: type description here.
    KHELIOS: TODO: type description here.
    KAPPMARKETPLACE: TODO: type description here.
    KLICENSE: TODO: type description here.
    KSECURITY: TODO: type description here.
    KUPGRADE: TODO: type description here.
    KCLUSTERMANAGEMENT: TODO: type description here.
    KAUDITLOG: TODO: type description here.
    KNETWORKING: TODO: type description here.
    KCONFIGURATION: TODO: type description here.
    KSTORAGEUSAGE: TODO: type description here.
    KFAULTTOLERANCE: TODO: type description here.
    KBACKUPRESTORE: TODO: type description here.
    KARCHIVALRESTORE: TODO: type description here.
    KREMOTEREPLICATION: TODO: type description here.
    KQUOTA: TODO: type description here.
    KCDP: TODO: type description here.
    KVIEWFAILOVER: TODO: type description here.
    KDISASTERRECOVERY: TODO: type description here.


    """

    KDISK = 'kDisk'

    KNODE = 'kNode'

    KCLUSTER = 'kCluster'

    KCHASSIS = 'kChassis'

    KPOWERSUPPLY = 'kPowerSupply'

    KCPU = 'kCPU'

    KMEMORY = 'kMemory'

    KTEMPERATURE = 'kTemperature'

    KFAN = 'kFan'

    KNIC = 'kNIC'

    KFIRMWARE = 'kFirmware'

    KNODEHEALTH = 'kNodeHealth'

    KOPERATINGSYSTEM = 'kOperatingSystem'

    KDATAPATH = 'kDataPath'

    KMETADATA = 'kMetadata'

    KINDEXING = 'kIndexing'

    KHELIOS = 'kHelios'

    KAPPMARKETPLACE = 'kAppMarketPlace'

    KLICENSE = 'kLicense'

    KSECURITY = 'kSecurity'

    KUPGRADE = 'kUpgrade'

    KCLUSTERMANAGEMENT = 'kClusterManagement'

    KAUDITLOG = 'kAuditLog'

    KNETWORKING = 'kNetworking'

    KCONFIGURATION = 'kConfiguration'

    KSTORAGEUSAGE = 'kStorageUsage'

    KFAULTTOLERANCE = 'kFaultTolerance'

    KBACKUPRESTORE = 'kBackupRestore'

    KARCHIVALRESTORE = 'kArchivalRestore'

    KREMOTEREPLICATION = 'kRemoteReplication'

    KQUOTA = 'kQuota'

    KCDP = 'kCDP'

    KVIEWFAILOVER = 'kViewFailover'

    KDISASTERRECOVERY = 'kDisasterRecovery'

